@@ -110,8 +110,8 @@ CELERY_BEAT_SCHEDULE = {
 # Database
 # ========
 #: Database URI including user and password
-SQLALCHEMY_DATABASE_URI = \
-    'postgresql+psycopg2://oarepo-micro-api:oarepo-micro-api@localhost/oarepo-micro-api'
+# SQLALCHEMY_DATABASE_URI = \
+#     'postgresql+psycopg2://oarepo-micro-api:oarepo-micro-api@localhost/oarepo-micro-api'
 
 # Flask configuration
 # ===================
@@ -162,3 +162,5 @@ USERPROFILES_EXTEND_SECURITY_FORMS = True
 SECURITY_SEND_REGISTER_EMAIL = False
 # Disable account confirmation requirement
 SECURITY_CONFIRMABLE = False
+
+from . import alias_prefix_replacer  # noqa to register app loaded event
